# snowprofile

Toolbox to read, write and browse snow profile data with python.

It includes tools to read/writes files in the [CAAML Snow Profile](http://caaml.org/Schemas/SnowProfileIACS/index.html) format.o

It also include basic python plotting tools for snow profiles.

The full documentation is available at [https://snowprofile.readthedocs.io](https://snowprofile.readthedocs.io/en/latest/)
